==> google-cloud-beyondcorp-appconnections-0.4.1.tar.gz: google-cloud-beyondcorp-appconnections-0.4.1/google/cloud/beyondcorp_appconnections_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.beyondcorp_appconnections import gapic_version as package_version

__version__ = package_version.__version__


from .services.app_connections_service import (
    AppConnectionsServiceAsyncClient,
    AppConnectionsServiceClient,
)
from .types.app_connections_service import (
    AppConnection,
    AppConnectionOperationMetadata,
    CreateAppConnectionRequest,
    DeleteAppConnectionRequest,
    GetAppConnectionRequest,
    ListAppConnectionsRequest,
    ListAppConnectionsResponse,
    ResolveAppConnectionsRequest,
    ResolveAppConnectionsResponse,
    UpdateAppConnectionRequest,
)

__all__ = (
    "AppConnectionsServiceAsyncClient",
    "AppConnection",
    "AppConnectionOperationMetadata",
    "AppConnectionsServiceClient",
    "CreateAppConnectionRequest",
    "DeleteAppConnectionRequest",
    "GetAppConnectionRequest",
    "ListAppConnectionsRequest",
    "ListAppConnectionsResponse",
    "ResolveAppConnectionsRequest",
    "ResolveAppConnectionsResponse",
    "UpdateAppConnectionRequest",
)

==> google-cloud-beyondcorp-appconnections-0.4.2.tar.gz: google-cloud-beyondcorp-appconnections-0.4.2/google/cloud/beyondcorp_appconnections_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.beyondcorp_appconnections_v1 import gapic_version as package_version

__version__ = package_version.__version__


from .services.app_connections_service import (
    AppConnectionsServiceAsyncClient,
    AppConnectionsServiceClient,
)
from .types.app_connections_service import (
    AppConnection,
    AppConnectionOperationMetadata,
    CreateAppConnectionRequest,
    DeleteAppConnectionRequest,
    GetAppConnectionRequest,
    ListAppConnectionsRequest,
    ListAppConnectionsResponse,
    ResolveAppConnectionsRequest,
    ResolveAppConnectionsResponse,
    UpdateAppConnectionRequest,
)

__all__ = (
    "AppConnectionsServiceAsyncClient",
    "AppConnection",
    "AppConnectionOperationMetadata",
    "AppConnectionsServiceClient",
    "CreateAppConnectionRequest",
    "DeleteAppConnectionRequest",
    "GetAppConnectionRequest",
    "ListAppConnectionsRequest",
    "ListAppConnectionsResponse",
    "ResolveAppConnectionsRequest",
    "ResolveAppConnectionsResponse",
    "UpdateAppConnectionRequest",
)
